function PublicationStyle(aAx)
% Optimizes the contents of an axes object for publishing.
%
% This function changes the plotting style of a figure, so that the plot
% prints nicely in a journal publication. Compared to the plotting style
% produced by PrintStyle, lines are thicker, markers are bigger, and font
% sizes are bigger. The function also turns the axes grid off, and removes
% the figure title. This style is good for small figures in publications.
% The plot is simplified to make it as legible as possible in a small
% format. For more detailed plots suitable for exact measurements,
% PrintStyle and ScreenStyle are recommended.
%
% Inputs:
% aAx - Axes object in which the plotting style will be changed.
%
% See also:
% ApplyStyle, NoStyle, ScreenStyle, PrintStyle

axFuns = {...
    @(a)grid(a, 'off'),...
    @(a)title(a, '')};

axProps = {...
    'FontSize', 15,...
    'TickDir', 'out',...
    'Box', 'off',...
    'Linewidth', 2};

titleProps = {...
    'FontSize', 15};

labelProps = {...
    'Fontsize', 15};

lineProps = {...
    'Linewidth', 4};

legendProps = {...
    'FontSize', 15};

legendPatchProps = {...
    'LineWidth', 2,...
    'xData', [0.0475 0.0475 0.0475+0.115 0.0475+0.115]};

ApplyStyle(...
    aAx,...
    axFuns,...
    axProps,...
    titleProps,...
    labelProps,...
    lineProps,...
    legendProps,...
    legendPatchProps)
end