function ScreenStyle(aAx)
% Optimizes the contents of an axes object for display on a screen.
%
% This function changes the plotting style of a figure, so that the plot
% displays nicely on a screen. The settings are similar to the default
% settings in MATLAB. Lines are thin, markers are small, and font sizes are
% small. The function also turns the axes grid on. This style makes it easy
% to see fine details in the plot.
%
% Inputs:
% aAx - Axes object in which the plotting style will be changed.
%
% See also:
% ApplyStyle, NoStyle, PrintStyle, PublicationStyle

axFuns = {...
    @(a)grid(a, 'on')};

axProps = {...
    'FontSize', 10,...
    'TickDir', 'in',...
    'LineWidth', 0.5,...
    'Box', 'on'};

titleProps = {...
    'FontSize', 11};

labelProps = {...
    'Fontsize', 11};

lineProps = {...
    'Linewidth', 0.5};

legendProps = {...
    'FontSize', 9};

legendPatchProps = {};

ApplyStyle(...
    aAx,...
    axFuns,...
    axProps,...
    titleProps,...
    labelProps,...
    lineProps,...
    legendProps,...
    legendPatchProps)
end