function OptimizeLinking2024(aExPaths, aSettingsToOptimize, aMaxIter)
% Optimize linking on the datasets for CTC 2024.

exDirs = FileEnd(aExPaths);

DeleteOldOptimizationCellData2024(aExPaths)

for i = 1:length(aExPaths)
    fprintf('Processing experiment %d / %d %s\n', i, length(aExPaths), aExPaths{i})
    exPath = aExPaths{i};
    seqDirs = GetSeqDirs(exPath);
    seqPaths = fullfile(exPath, seqDirs);
    
    % Read initial settings.
    initialImData = [];
    for j = 1:length(seqDirs)
        seqPath = fullfile(aExPaths{i}, seqDirs{j});
        settingsPath = fullfile(exPath, 'SettingsLinks_clean.csv');
        imData = ImageData(seqPath, 'SettingsFile', settingsPath);
        initialImData = [initialImData; imData];
    end
    
    % Specify where the optimized settings should be saved.
    optimizedSettingsPaths = cell(size(seqDirs));
    for j = 1:length(seqDirs)
        optimizedSettingsPaths{j} = fullfile(exPath, 'SettingsLinks_optimized_LNK.csv');
    end
    
    % Specify where the linking optimizer should be saved.
    optimizerSavePath = fullfile(exPath,...
        'Analysis',...
        'LinkingOptimizers',...
        [exDirs{i} datestr(now, '_yymmdd_HHMMss') '.mat']);
    
    optimizer = TRAOptimizerEx(seqPaths, aSettingsToOptimize,...
        'SavePaths', optimizedSettingsPaths,...
        'OptimizerSavePath', optimizerSavePath,...
        'InitialImData', initialImData,...
        'ScoringFunction', 'LNK',...
        'Plot', true);
    
    optimizer.Optimize_coordinatedescent('MaxIter', aMaxIter)
end