function SetVisibleMenus(aMenus, aLevel)
% Sets the visibility of a set of menus based on their levels.
%
% This function can be used to display an appropriate set of menus when a
% user selects a level ('basic', 'advanced' or 'development') in a GUI. The
% menus are represented using a cell array with 4 columns, where each row
% corresponds to a menu. The first column contains the menu names, the
% second column contains the levels of the menus, the third column contains
% callbacks or cell arrays with sub-menus and the fourth column contains
% the uimenu objects. This cell array is normally generated by CreateMenus.
% The function is recursive.
%
% Inputs:
% aMenus - Cell array representing the menus.
% aLevel - The level that should be made visible. If 'advanced' or
%          'development' are selected, all lower levels will also be made
%          visible.
%
% See also:
% CreateMenus, GetMenu

% Make lower levels visible too.
switch aLevel
    case 'basic'
        visibleLevels = {'basic'};
    case 'advanced'
        visibleLevels = {'basic' 'advanced'};
    case 'development'
        visibleLevels = {'basic' 'advanced' 'development'};
end

for i = 1:size(aMenus,1)
    if any(strcmp(visibleLevels, aMenus{i,2}))
        set(aMenus{i,4}, 'Visible', 'on')
        if iscell(aMenus{i,3})
            % Set the visibility of sub-menus.
            SetVisibleMenus(aMenus{i,3}, aLevel)
        end
    else
        set(aMenus{i,4}, 'Visible', 'off')
        % Sub-menus will not be visible.
    end
end
end