function Train_2024(aExDir)
% Optimizes track linking parameters for the linking challenge in CTC 2024.
%
% Inputs:
% aExDir - 

swPath = fileparts(mfilename('fullpath'));
subdirs = textscan(genpath(swPath), '%s', 'delimiter', pathsep);
addpath(subdirs{1}{:});

if contains(aExDir, '3D')
    settingsToOptimize = {
        'TrackXSpeedStd'
        'TrackZSpeedStd'
        'TrackPAppear'
        'TrackPDisappear'
        'pCnt0'
        'pCnt1'
        'pCnt2'
        'pSplit'
        };
else
    settingsToOptimize = {
        'TrackXSpeedStd'
        'TrackPAppear'
        'TrackPDisappear'
        'pCnt0'
        'pCnt1'
        'pCnt2'
        'pSplit'
        };
end

exPath = fullfile(fileparts(swPath), aExDir);

DeleteOldOptimizationCellData2024({exPath})

seqDirs = GetSeqDirs(exPath);
seqDirs = regexp(seqDirs, '.*(?<!(_GT|_ST|_ERR_SEG|_RES))$', 'match', 'once');
seqDirs = seqDirs(~cellfun(@isempty, seqDirs));
seqPaths = fullfile(exPath, seqDirs);

% Read initial settings.
initialImData = [];
for j = 1:length(seqDirs)
    seqPath = fullfile(exPath, seqDirs{j});
    settingsPath =...
        fullfile(swPath,...
        'Files',...
        'Settings',...
        sprintf('CTC2024_clean'),...
        sprintf('Settings_ISBI_2024_Training_%s-%s_clean.csv', aExDir, seqDirs{j}));
    imData = ImageData(seqPath, 'SettingsFile', settingsPath);
    initialImData = [initialImData; imData]; %#ok<AGROW>
end

% Specify where the optimized settings should be saved.
optimizedSettingsPaths = cell(size(seqDirs));
for j = 1:length(seqDirs)
    optimizedSettingsPaths{j} =...
        fullfile(swPath,...
        'Files',...
        'Settings',...
        'CTC2024_optimized_LNK',...
        sprintf('Settings_ISBI_2024_Training_%s-%s_optimized_LNK_new.csv', aExDir, seqDirs{j}));
end

optimizer = TRAOptimizerEx(seqPaths, settingsToOptimize,...
    'SavePaths', optimizedSettingsPaths,...
    'InitialImData', initialImData,...
    'ScoringFunction', 'LNK',...
    'Plot', true);

optimizer.Optimize_coordinatedescent('MaxIter', 10)